-------------------
:mod:`fugw.solvers`
-------------------

Under the hood, classes in :mod:`fugw.mappings` call solvers
implemented in :mod:`fugw.solvers`.

.. currentmodule:: fugw.solvers

.. autosummary::
   :toctree: generated/
   :template: class.rst

   FUGWSolver
   FUGWSparseSolver
